@@ -52,6 +52,7 @@ import tools
 import fields
 import unicode_csv
 import inspect
+from pprint import pprint
 
 from constants_and_vars import STATS
 from constants_and_vars import FORMAT
@@ -717,9 +718,10 @@ class Import_session(object):
         the same model
 
         """
-        if 'CREATED::id' in self.mapping[model]\
-                and self.mapping[model]['CREATED::id']:
-            return self.mapping[model]['CREATED::id']
+        if 'id' in self.mapping[model]\
+                and self.mapping[model]['id'] \
+                and isinstance(self.mapping[model]['id'], int):
+            return int(self.mapping[model]['id'])
         return False
 
     def _unique_relation(self, model, data, search):
@@ -730,16 +732,17 @@ class Import_session(object):
         for each_model in self.mapping:
             if _get_special_actions(each_model)['unique']\
                     and model.split('::')[1] == each_model.split('::')[1]:
-                if 'CREATED::id' in self.mapping[each_model]\
-                        and self.mapping[each_model]['CREATED::id']:
+                if 'id' in self.mapping[each_model]\
+                        and self.mapping[each_model]['id'] \
+                        and isinstance(self.mapping[model]['id'], int):
                     search = data.keys()
                     search.remove('CREATED::search')
                     res = self._search(model.split('::')[1], data, search)
                     if res\
-                    and self.mapping[each_model]['CREATED::id'] in res:
+                    and self.mapping[each_model]['id'] in res:
                         self._logger.debug('<%20s> UNIQUE Replacement' %\
                                 model, extra=STATS[self._id])
-                        return self.mapping[each_model]['CREATED::id']
+                        return int(self.mapping[each_model]['id'])
         return False
 
     def _create_relation(self, line, model):
@@ -754,10 +757,9 @@ class Import_session(object):
 
         if not isinstance(data_rels, list):
             data_rels = [data_rels]
-        
         for data_rel in data_rels:
-            if 'CREATED::id' in data_rel:
-                id_ = data_rel['CREATED::id']
+            if 'id' in data_rel and isinstance(data_rel['id'], int):
+                id_ = int(data_rel['id'])
             else:
                 if 'CREATED::search' in data_rel:
                     search_rel = data_rel['CREATED::search']
@@ -784,7 +786,7 @@ class Import_session(object):
                 if not id_:
                     (state, model, id_) = self._create(model,
                             data_rel, search_rel)
-                data_rel['CREATED::id'] = id_
+                data_rel['id'] = id_
         return id_
 
     #===========================================================================
@@ -1113,7 +1115,6 @@ formed, \n\n" % (model, attr)
         res = [False]
         error = None
         state = 'old'
-
         # Manage null values
         for attr, value in data.items():
             try:
@@ -1125,15 +1126,11 @@ formed, \n\n" % (model, attr)
 
         search = self._search(model, data, search)
 
-        if 'CREATED::id' in data and data['CREATED::id']:
-            res = [int(data['CREATED::id'])]
-            del data['CREATED::id']
+        if 'id' in data and data['id'] and isinstance(data['id'], int):
+            res = [int(data['id'])]
             self._logger.info("<%-25s> ALREADY%s" % (model, res),
                     extra=STATS[self._id])
         else:
-            if 'id' in data:
-                search = [int(data['id'])]
-                del data['id']
 
             self._logger.debug('<%-25s> data:%s' % (model, data),
                     extra=STATS[self._id])
@@ -1184,16 +1181,23 @@ formed, \n\n" % (model, attr)
                     
                 except xmlrpclib.Fault as err:
                     try:
-                        error = unicode(err.faultString.split('\n')[-2])
+                        err = unicode(err.faultString.split('\n')[-2])
+                        error = err.count('\n') and err.split(u'\n')[-1] or err.split(u'\n')[-2] or [err]
                     except:
-                        error = unicode(err.faultString + (err.faultCode or ''))\
-                            or 'Unknown error (xmlrplib.Fault)'
+                        try:
+                            err = unicode(err.faultString + (err.faultCode or ''))
+                            error = err.count(u'\n') and err.split(u'\n')[-1] or err.split(u'\n')[-2] \
+                                or u'Unknown error (xmlrplib.Fault)'
+                            error = u'OERP => ' + error
+                        except Exception as err:
+                            error = u'Traceback unreadable (%s)' % err
                 except Exception as err:
-                    error = unicode(err) or 'Unknown error (Exception)'
+                    err = unicode(err)
+                    error = err.count(u'\n') and err.split(u'\n')[-1] or err.split(u'\n')[-2] \
+                            or u'Unknown error (Exception)'
         if error:
-            res = [False]
             state = 'none'
-            self._logger.error("<%-25s> id:%s %s" %\
+            self._logger.error("<%-25s> %s %s" %\
                     (model, search, error), extra=STATS[self._id])
             self._logger.debug("<%-25s> id:%s|state:%s|%s" %\
                 (model, search, state, pformat(data)), extra=STATS[self._id])
@@ -1201,7 +1205,7 @@ formed, \n\n" % (model, attr)
             STATS['objects'][model]['skipped'] += 1
             STATS['objects'][model]['error'] += 1
         
-        data['CREATED::id'] = res[0]
+        data['id'] = res[0]
         return (state, model, res[0])
 
     def _apply_model(self, model, line):
@@ -1396,16 +1400,16 @@ formed, \n\n" % (model, attr)
                 data[item] = content
 
             #Cleaning dict items with null value
-            if not data[item]:
-                if required:
-                    raise exceptions.RequiredFieldError(model,
-                            item, data[item], line, logger=self._logger)
-                if data[item] not in (0, False):
-                    ToRemove.append(item)
+            #if not data[item]:
+            #    if required:
+            #        raise exceptions.RequiredFieldError(model,
+            #                item, data[item], line, logger=self._logger)
+            #    if data[item] not in (0, False):
+            #        ToRemove.append(item)
 
         # Cleaning data from given attributes
-        for item in ToRemove:
-            del data[item]
+        #for item in ToRemove:
+        #    del data[item]
         
         # Adding this to indicate that this field has been loaded
         data['CREATED::search'] = search
