@@ -209,8 +209,8 @@ def get_ids(model, fields, op='&'):
         except RuntimeError:
             return self._get_ids(b_model, b_field, b_value, b_line)
         if not res:
-            self._logger.error(u"'%s' not found in fields %s from %s" %
-                    (b_value, fields, model), extra=STATS[self._id])
+            self._logger.error(u"<%-30s> '%s' not found in fields %s" %
+                    (model, b_value, fields), extra=STATS[self._id])
         return res
     
     return _get_ids
