@@ -54,8 +54,8 @@ class RequiredFieldError(BaseException):
                     % (model, field, value, line)
         else:
             msg = field
-        if logger:
-            logger.info("<%-20s> %s" % (model, msg), extra=STATS)
+        #if logger:
+        #    logger.info("<%-20s> %s" % (model, msg), extra=STATS)
         super(RequiredFieldError, self).__init__(msg)
 
 
@@ -76,8 +76,8 @@ class ColumnIndexError(IndexError):
                     % (model, field, value, column)
         else:
             msg = field
-        if logger:
-            logger.info("<%-20s> %s" % (model, msg), extra=STATS)
+        #if logger:
+        #    logger.info("<%-20s> %s" % (model, msg), extra=STATS)
         super(ColumnIndexError, self).__init__(msg)
 
 
@@ -100,8 +100,8 @@ class SkipLineException(BaseException):
                 % (field, value, line)
         else:
             msg = field
-        if logger:
-            logger.info("<%-20s> %s" % (model, msg), extra=STATS)
+        #if logger:
+        #    logger.info("<%-20s> %s" % (model, msg), extra=STATS)
         super(SkipLineException, self).__init__(msg)
 
 
@@ -119,12 +119,15 @@ class SkipObjectException(BaseException):
         :type msg: str
 
         """
+        global STATS
         if line is None:
             msg = "Skipped object for field '%s'('%s') at line %s"\
                     % (field, value, line)
         else:
             msg = field
         if logger:
-            logger.info("<%-20s> %s" % (model, msg), extra=STATS)
+            if 'line_num' not in STATS:
+                STATS['line_num'] = -2 
+            logger.info("<%-20s> %s skipped" % (model, msg), extra=STATS)
         super(SkipObjectException, self).__init__(msg)
 
